#ifndef __STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINOUS_HPP__
#define __STAN__PROB__DISTRIBUTIONS__MULTIVARIATE__CONTINUOUS_HPP__

#include <stan/prob/distributions/multivariate/continuous/gaussian_dlm_obs.hpp>
#include <stan/prob/distributions/multivariate/continuous/matrix_normal.hpp>
#include <stan/prob/distributions/multivariate/continuous/multi_normal.hpp>
#include <stan/prob/distributions/multivariate/continuous/multi_normal_cholesky.hpp>
#include <stan/prob/distributions/multivariate/continuous/multi_normal_prec.hpp>
#include <stan/prob/distributions/multivariate/continuous/multi_gp.hpp>
#include <stan/prob/distributions/multivariate/continuous/multi_student_t.hpp>
#include <stan/prob/distributions/multivariate/continuous/wishart.hpp>
#include <stan/prob/distributions/multivariate/continuous/inv_wishart.hpp>
#include <stan/prob/distributions/multivariate/continuous/dirichlet.hpp>
#include <stan/prob/distributions/multivariate/continuous/lkj_corr.hpp>
#include <stan/prob/distributions/multivariate/continuous/lkj_cov.hpp>

#endif
